/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DRender.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DRender/qabstractfunctor.sip"
#include <qabstractfunctor.h>
#line 31 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractFunctor.cpp"

#line 166 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 35 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DRender/sipQt3DRenderQt3DRenderQAbstractFunctor.cpp"


class sipQt3DRender_QAbstractFunctor : public ::Qt3DRender::QAbstractFunctor
{
public:
    sipQt3DRender_QAbstractFunctor();
    virtual ~sipQt3DRender_QAbstractFunctor();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::qintptr id() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DRender_QAbstractFunctor(const sipQt3DRender_QAbstractFunctor &);
    sipQt3DRender_QAbstractFunctor &operator = (const sipQt3DRender_QAbstractFunctor &);

    char sipPyMethods[1];
};

sipQt3DRender_QAbstractFunctor::sipQt3DRender_QAbstractFunctor(): ::Qt3DRender::QAbstractFunctor(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DRender_QAbstractFunctor::~sipQt3DRender_QAbstractFunctor()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

::qintptr sipQt3DRender_QAbstractFunctor::id() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractFunctor, sipName_id);

    if (!sipMeth)
        return ::qintptr();

    extern ::qintptr sipVH_Qt3DRender_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_Qt3DRender_0(sipGILState, sipImportedVirtErrorHandlers_Qt3DRender_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_Qt3DRender_QAbstractFunctor_id, "id(self) -> PyQt5.sip.voidptr");

extern "C" {static PyObject *meth_Qt3DRender_QAbstractFunctor_id(PyObject *, PyObject *);}
static PyObject *meth_Qt3DRender_QAbstractFunctor_id(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::Qt3DRender::QAbstractFunctor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DRender_QAbstractFunctor, &sipCpp))
        {
            ::qintptr*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractFunctor, sipName_id);
                return SIP_NULLPTR;
            }

            sipRes = new ::qintptr(sipCpp->id());

            return sipConvertFromNewType(sipRes, sipType_qintptr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractFunctor, sipName_id, doc_Qt3DRender_QAbstractFunctor_id);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DRender_QAbstractFunctor(void *, int);}
static void release_Qt3DRender_QAbstractFunctor(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQt3DRender_QAbstractFunctor *>(sipCppV);
    else
        delete reinterpret_cast< ::Qt3DRender::QAbstractFunctor *>(sipCppV);
}


extern "C" {static void dealloc_Qt3DRender_QAbstractFunctor(sipSimpleWrapper *);}
static void dealloc_Qt3DRender_QAbstractFunctor(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DRender_QAbstractFunctor *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DRender_QAbstractFunctor(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DRender_QAbstractFunctor(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DRender_QAbstractFunctor(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQt3DRender_QAbstractFunctor *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQt3DRender_QAbstractFunctor();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt3DRender_QAbstractFunctor[] = {
    {sipName_id, meth_Qt3DRender_QAbstractFunctor_id, METH_VARARGS, doc_Qt3DRender_QAbstractFunctor_id}
};

PyDoc_STRVAR(doc_Qt3DRender_QAbstractFunctor, "\1QAbstractFunctor()");


static pyqt5ClassPluginDef plugin_Qt3DRender_QAbstractFunctor = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DRender_Qt3DRender_QAbstractFunctor = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DRender__QAbstractFunctor,
        SIP_NULLPTR,
        &plugin_Qt3DRender_QAbstractFunctor,
    },
    {
        sipNameNr_QAbstractFunctor,
        {0, 0, 1},
        1, methods_Qt3DRender_QAbstractFunctor,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DRender_QAbstractFunctor,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DRender_QAbstractFunctor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DRender_QAbstractFunctor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_Qt3DRender_QAbstractFunctor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::Qt3DRender::QAbstractFunctor),
};
